EditorLang class
Constructors
Properties
- editor_blur → String
-
Blurno setter - editor_color → String
-
Color Adjustmentno setter - editor_color_bg → String
-
Exposureno setter - editor_color_bhd → String
-
Saturationno setter - editor_color_bph → String
-
Balanceno setter - editor_color_bph_blue → String
-
Blueno setter - editor_color_bph_green → String
-
Greenno setter - editor_color_bph_red → String
-
Redno setter - editor_color_dbd → String
-
Contrastno setter - editor_color_delete_pf_faild → String
-
Delete Failedno setter - editor_color_delete_pf_successfully → String
-
Delete Successfullyno setter - editor_color_effect_name → String
-
Nameno setter - editor_color_effect_save_action → String
-
Saveno setter - editor_color_effect_save_action_tip → String
-
Please enter the effect nameno setter - editor_color_effect_save_no → String
-
Cancelno setter - editor_color_effect_save_tip → String
-
Save the effect for one-click use next time before applying the color effect?no setter - editor_color_gg → String
-
Highlightsno setter - editor_color_ld → String
-
Brightnessno setter - editor_color_pf → String
-
Formulano setter - editor_color_pf_no → String
-
No Formulano setter - editor_color_rh → String
-
Sharpenno setter - editor_color_save_pf_faild → String
-
Failed to save effectno setter - editor_color_save_pf_successfully → String
-
Save effect successfullyno setter - editor_color_sd → String
-
Hueno setter - editor_color_sw → String
-
Temperatureno setter - editor_color_xyd → String
-
Vividnessno setter - editor_color_yy → String
-
Shadowsno setter - editor_color_yying → String
-
Vignetteno setter - editor_color_yying_dx → String
-
Sizeno setter - editor_color_yying_sx → String
-
Up and downno setter - editor_color_yying_wy → String
-
Extensionno setter - editor_color_yying_zy → String
-
Left and rightno setter - editor_color_zd → String
-
Noiseno setter - editor_crop → String
-
Cropno setter - editor_crop_freedom → String
-
Freeno setter - editor_crop_orignal → String
-
Originalno setter - editor_exit_no → String
-
Cancelno setter - editor_exit_save → String
-
Saveno setter - editor_exit_tip → String
-
Do you want to save the edited effects before exiting?no setter - editor_filter → String
-
Filterno setter - editor_frame → String
-
borderno setter - editor_intensity → String
-
Intensityno setter - editor_name → String
-
Image Editingno setter - editor_restore → String
-
Resetno setter - editor_rotate → String
-
Rotateno setter - editor_rotate_l90 → String
-
Turn 90°no setter - editor_rotate_lr → String
-
Horizontalno setter - editor_rotate_r90 → String
-
Turn 90°no setter - editor_rotate_tb → String
-
Verticalno setter - editor_sticker → String
-
Stickersno setter - editor_text → String
-
Textno setter - editor_text_align → String
-
alignno setter - editor_text_align_center → String
-
centerno setter - editor_text_align_left → String
-
leftno setter - editor_text_align_ls → String
-
lineno setter - editor_text_align_right → String
-
rightno setter - editor_text_align_ws → String
-
wordno setter - editor_text_font → String
-
fontno setter - editor_text_style → String
-
styleno setter - editor_text_style_alpha → String
-
transparentno setter - editor_text_style_alpha_2 → String
-
Transparencyno setter - editor_text_style_ct → String
-
boldno setter - editor_text_style_xhx → String
-
underlineno setter - editor_text_style_xt → String
-
italicno setter - editor_vip_action → String
-
Buy VIPno setter - editor_vip_cancel → String
-
Give upno setter - editor_vip_limited_1 → String
-
activate VIP to use exclusive material functionsno setter - editor_vip_limited_2 → String
-
You have used VIP filters. Please save the filter effects after activating VIP?no setter - editor_vip_limited_3 → String
-
You have used VIP materials. Please save the effects after activating membership?no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → EditorLang
-
no setter
Static Methods
-
load(
Locale locale) → Future< EditorLang> -
maybeOf(
BuildContext context) → EditorLang? -
of(
BuildContext context) → EditorLang
Constants
- delegate → const AppLocalizationDelegate