ImageBinaryDataItem class

Inheritance

Constructors

ImageBinaryDataItem(String name, Uint8List bytes, {DataItemMetadata? metadata, String disPlayName = ''})

Properties

bytes → Uint8List
finalinherited
disPlayName ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
metadata → DataItemMetadata?
finalinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited