CustomTrackShape class

Inheritance

Constructors

CustomTrackShape({double activeTrackHeight = 4.0, double inactiveTrackHeight = 4.0, double borderWidth = 1.0, required double thumbSize, Color borderColor = const Color(0xff656566)})

Properties

activeTrackHeight → double
final
borderColor → Color
final
borderWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveTrackHeight → double
final
isRounded → bool
Whether the track shape is rounded.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbSize → double
final

Methods

getPreferredRect({required RenderBox parentBox, Offset offset = Offset.zero, required SliderThemeData sliderTheme, bool isEnabled = false, bool isDiscrete = false}) → Rect
Returns the preferred bounds of the shape.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, {required RenderBox parentBox, required SliderThemeData sliderTheme, required Animation<double> enableAnimation, required Offset thumbCenter, Offset? secondaryOffset, bool isEnabled = false, bool isDiscrete = false, required TextDirection textDirection}) → void
Paints the track shape based on the state passed to it.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited